--[[
#########################################################################################
# THE GAME CONTROL CLASS - handles a tetris game; contais a cBoard class object			#
#########################################################################################
# Belongs to the LÖVE-ly Tetris project													#
# tv_user - 2012																		#
# Free to use for all purposes															#
#########################################################################################
--]]

cGameControl = {}
cGameControl.__index = cGameControl


-- THIS FUNCTION CREATES THE GAME CONTROL OBJECT
function cGameControl.create(px, py, nextx, nexty) -- px and py are the coordinates to the top-left corner of the board; nextx and nexty are the relative displacement to position the nextpiece where it must be drawn
	
	local temp = {} -- first create a temp table
	setmetatable(temp, cGameControl) -- make its metatable this very own (cBoard)
	-- set initial vars
	-- 1. create a board to play the tetris
	temp.Board = cBoard.create (px, py)
	temp.Board:ResetBoard()
	-- 2. create the first tetris piece
    temp.mPiece          = math.random(1,5) -- never start with a Z or S piece
    temp.mRotation       = 1
    temp.mPosX           = (bW / 2) + cPieces.InitPos[temp.mPiece][temp.mRotation][1]
    temp.mPosY           = cPieces.InitPos[temp.mPiece][temp.mRotation][2]
    -- 3. create the next one
	-- randomize pieces at the beggining of the game
	shuffle(cGenerator.sequence)
	cGenerator.element = 1
	-- new piece vars
    temp.mNextPiece      =  cGenerator:getNewPiece()
    temp.mNextRotation   = 1
    temp.mNextPosX = bW + nextx
    temp.mNextPosY = nexty
    -- 4. create the score and other vars
    temp.score 			= 0					-- score!
    temp.timeElapsed    = 0					-- temp var to hold time elapsed (for dropping the piece)
    temp.IsGameOver     = false 			-- holds if game is over
    temp.IsVictory		= false 			-- holds if player emptied the board and so call a victory event
	temp.WAIT_TIME 		= INIT_WAIT_TIME 	-- at the beginning of the game, reset the wait time
	temp.level			= 1 				-- var to hold current level
	temp.pause			= false				-- holds if game is paused
	temp.totaltime		= 0 				-- var to hold total game time
    -- return the table
	return temp
	
end


-- Creates a new piece, i.e., makes the nextpiece the current one and randomises a new next piece
function cGameControl:CreateNewPiece ()
    self.mPiece          = self.mNextPiece
    self.mRotation       = self.mNextRotation
    self.mPosX           = (bW / 2) + cPieces.InitPos[self.mPiece][self.mRotation][1]
    self.mPosY           = cPieces.InitPos[self.mPiece][self.mRotation][2]
    -- Next piece vars
    -- get a next piece by summoning the generator
    self.mNextPiece      = cGenerator:getNewPiece()
end	


-- Draws a given piece in a give position
function cGameControl:DrawPiece (pX, pY, piece, rotation, afterimage)
	love.graphics.setLine(1, "smooth") -- first set line options
	-- first compute and store the actual pixel coordinates
	for i = 1, nPBlocks do
		for j = 1, nPBlocks do
			if (cPieces.PieceStruct[piece][rotation][i][j] ~= 0) then
				-- if player is holding the down key and we're drawing the main piece, we'll do an afterimage effect
				if (love.keyboard.isDown(PcontrolMap[4]) and afterimage) then
					-- change the alpha value of the color and...
					color[piece][4] = 50
					--  draw 1 after image...
					love.graphics.setColor(color[piece]) -- use respective color
					love.graphics.rectangle("fill", (self.Board.PosX+((pX+j-2)*blockSize)),
													(self.Board.PosY+((pY+i-4)*blockSize)),
													(blockSize-1),
													(blockSize-1))
					-- ...and the second one
					color[piece][4] = 125
					love.graphics.setColor(color[piece]) -- use respective color
					love.graphics.rectangle("fill", (self.Board.PosX+((pX+j-2)*blockSize)),
													(self.Board.PosY+((pY+i-3)*blockSize)),
													(blockSize-1),
													(blockSize-1))

					-- finally, restore the original alpha value
					color[piece][4] = 255

				end
				love.graphics.setColor(color[piece]) -- use respective color
				love.graphics.rectangle("fill", (self.Board.PosX+((pX+j-2)*blockSize)),
												(self.Board.PosY+((pY+i-2)*blockSize)),
												(blockSize-1),
												(blockSize-1))
			end
		end
	end	
end


-- Draws the complete scene
function cGameControl:DrawScene ()
	-- Draw a background to the board
	love.graphics.setColor(color["darkback"]) -- use a dark blue color to shade the playfield
	love.graphics.rectangle("fill", self.Board.PosX, self.Board.PosY, bW * blockSize, bH * blockSize )
	-- Draw the board
	self.Board:DrawBoard ()
	-- Draw the current piece
	self:DrawPiece (self.mPosX, self.mPosY, self.mPiece, self.mRotation, true)
	-- Draw the next piece ONLY if blindmode is disabled
	if blindmode == 2 then self:DrawPiece (self.mNextPosX, self.mNextPosY, self.mNextPiece, self.mNextRotation, false)
	else
		-- draw an interrogation mark in its place
		love.graphics.setFont(font["smalltitle"]) -- set font
		love.graphics.setColor(color[5]) -- set color
		love.graphics.print("?", (self.Board.PosX+((self.mNextPosX+1)*blockSize)),(self.Board.PosY+(self.mNextPosY*blockSize)))
	end
end


-- Manage Input
function cGameControl:ManageInp (key)
	-- Check each key				
	-- 1. RIGHT
	if (key == PcontrolMap[1]) then
		if (self.Board:IsPossibleMovement (self.mPosX - 1, self.mPosY, self.mPiece, self.mRotation) == true) then
			self.mPosX = self.mPosX - 1
			--love.audio.play(aMove) --Play the sound
		end

	-- 2. LEFT
	elseif (key == PcontrolMap[2]) then
		if (self.Board:IsPossibleMovement (self.mPosX + 1, self.mPosY, self.mPiece, self.mRotation) == true) then
			self.mPosX = self.mPosX + 1
			--love.audio.play(aMove) --Play the sound

		end
	
	-- 3. ROTATE
	elseif (key == PcontrolMap[3]) then
		-- let's rotate the piece if possible
		local lol = self.mRotation
		lol = lol + 1
		if lol > 4 then lol = lol - 4 end
		if (self.Board:IsPossibleMovement(self.mPosX, self.mPosY, self.mPiece, lol) == true) then
			self.mRotation = lol
			--love.audio.play(aMove) --Play the sound
		end	
	
	-- 4. PAUSE
	elseif (key == PcontrolMap[5]) then
		self.pause = not self.pause
	end
end


-- Update the piece position according to time
function cGameControl:Update (tempo)
	-- check if game is not paused
	if (not self.pause) then
	
		-- check if down key is pressed, and if so, temporarily increase the wait_time
	
		-- first increase time counter
		self.timeElapsed = self.timeElapsed + (tempo * 1000)
		self.totaltime = self.totaltime + tempo
		-- then check if enough time passed
		
		if love.keyboard.isDown(PcontrolMap[4]) then
			if (self.timeElapsed >= 50) then
				-- increase score a little bit
				self.score = self.score + 1
				-- if so, drop the piece one block or store it if a collision happened
				if (self.Board:IsPossibleMovement (self.mPosX, self.mPosY + 1, self.mPiece, self.mRotation) == true) then
					self.mPosY = self.mPosY + 1
				else
					-- then lets store the piece in its last position
					self.Board:StorePiece (self.mPosX, self.mPosY, self.mPiece, self.mRotation)
					-- finally, whenever we store a piece, we must check if a line was completed and can be deleted
					self.IsVictory = self.Board:DeletePossibleLines()
					-- if player won (cleared the board), add a bonus to score and end game (at sSPGame.lua)
					if self.IsVictory == true then self.score = self.score + 10000 end
					-- CHECK IF GAME OVER
					if (self.Board:IsGameOver ()) then
						self.IsGameOver = true
						--self:UpdateScores ()
					end
					-- create a new piece
					self:CreateNewPiece ()
				end
				-- restart the time counter
				while self.timeElapsed >= 50 do
					self.timeElapsed = self.timeElapsed - 50
				end
				
			end
		else
			if (self.timeElapsed >= self.WAIT_TIME) then
				-- increase score a little bit
				self.score = self.score + 1
				-- if so, drop the piece one block or store it if a collision happened
				if (self.Board:IsPossibleMovement (self.mPosX, self.mPosY + 1, self.mPiece, self.mRotation) == true) then
					self.mPosY = self.mPosY + 1
				else
					-- then lets store the piece in its last position
					self.Board:StorePiece (self.mPosX, self.mPosY, self.mPiece, self.mRotation)
					-- finally, whenever we store a piece, we must check if a line was completed and can be deleted
					self.IsVictory = self.Board:DeletePossibleLines()
					-- if player won (cleared the board), add a bonus to score and end game
					if self.IsVictory == true then self.score = self.score + 10000 end
					-- CHECK IF GAME OVER
					if (self.Board:IsGameOver ()) then
						self.IsGameOver = true
						--self:UpdateScores ()
					end
					-- create a new piece
					self:CreateNewPiece ()
				end
				-- restart the time counter
				self.timeElapsed = self.timeElapsed - self.WAIT_TIME
			end

			--finally, check if the wait_time should be updated
			local v = self.score
			local c = 0
			while v >= 500 do
				v = v - 500
				c = c + 1
			end
			if c > (self.level - 1) then
				-- once every 500 points accelerate piece drop like this:
				-- ...increase level...
				self.level = self.level + 1
				-- ...decrease wait time but only until a certain amount (min 150)
				if (self.WAIT_TIME >= 200) then 
					self.WAIT_TIME = self.WAIT_TIME - 50
				end
			end

		end
	end
end