--[[
#########################################################################################
# THE HIGHSCORE SAVING SINGLETON CLASS - handles reading and writing data to file		#
#########################################################################################
--]]

cHighscores = {}

cHighscores.places = 10			-- number of highscores to save
cHighscores.score = {}			-- array of the actual scores
cHighscores.name = {}			-- array of the names matching the scores


-- Creates a new file and fill it with the standart scores
function cHighscores:new(filename, name, score)
	local file=love.filesystem.newFile(filename)
	file:open("w")
	for a=1, self.places do
		file:write(name.."\n"..score.."\n")
	end
	file:close()
end


-- Loads the highscores from file
function cHighscores:load(filename)
	local file=love.filesystem.newFile(filename)
	file:open("r")
	local a=1
	local stringtype=1
	for line in file:lines() do
		if stringtype==1 then
			self.name[a]=line
			stringtype=2
		else
			self.score[a]=tonumber(line)
			stringtype=1
			a=a+1
		end
	end
	file:close()
end


-- Saves the scores to the file
function cHighscores:save(filename)
	local file=love.filesystem.newFile(filename)
	file:open("w")
	for a=1, self.places do
		file:write(self.name[a].."\n"..self.score[a].."\n")
	end
	file:close()
end


-- Checks if a score is a new highscore and returns its position or (if not a highscore) returns false
function cHighscores:test(score)
	-- loop every score to see if it's bigger than any other
	for a = 1, self.places do
		-- if so
		if score > self.score[a] then
			--return its number
			return a
		end
	end
	-- not a highscore, then return false
	return false
end


-- Adds a score to the table
function cHighscores:add(score, name)
	-- loop every score to see if it's bigger than any other
	for a = 1, self.places do
		-- if so
		if score > self.score[a] then
			-- loop every other to displace them to the bottom
			for b = self.places, a+1, -1 do
				self.name[b]=self.name[b-1]
				self.score[b]=self.score[b-1]
			end
			-- save the nem score in its position
			self.score[a]=score
			self.name[a]=name
			-- quit loop
			break
		end
	end
end