--[[
#########################################################################################
# THE COMBO BUTTON CLASS - handles "combo" buttons										#
#########################################################################################
--]]

cCombo = {}
cCombo.__index = cCombo

-- THIS FUNCTION CREATES A BUTTON TABLE
function cCombo.create(label, text, x, y, font, offColor, onColor)
	
	local temp = {}
	setmetatable(temp, cCombo)
	
								-- SAVE SOME PROPERTIES
	temp.label = label
	temp.text = text			-- The various labels in the button
	temp.numT = #temp.text		-- The number of labels
	temp.activeT = 1			-- enables the first label
	temp.x = x					-- X pos
	temp.y = y					-- Y pos
	temp.font = font			-- The font used for this button
	temp.offColor = offColor	-- The text color while not active >> its a reference to a global table called color
	temp.onColor = onColor		-- The text color while active >> its a reference to a global table called color
	temp.hover = false 			-- If button is active or not

	return temp
	
end


-- THIS FUNCTION DRAWS THE BUTTON
function cCombo:draw()

	-- 1. set font
	love.graphics.setFont(font[self.font])
	-- 2. set color based on state
	if self.hover then
		love.graphics.setColor(color[self.onColor])
	else
		love.graphics.setColor(color[self.offColor])
	end
	-- 3. draw button label based on button type
	love.graphics.print(self.label .. ":\t\t< " .. self.text[self.activeT] .. " >", self.x, self.y) -- draw the text
	
end


-- THIS FUNCTION CHANGES THE BUTTON'S STATE
function cCombo:setHover (hover)

	self.hover = hover
	
end

-- THIS FUNCTION CHANGES THE BUTTON'S LABEL TO THE NEXT ONE ON THE LIST
function cCombo:nextLabel ()

	self.activeT = (self.activeT % self.numT) + 1	-- calculate next label and apply it
	
end


-- THIS FUNCTION CHANGES THE BUTTON'S LABEL TO THE PREVIOUS ONE ON THE LIST
function cCombo:previousLabel ()

	for i = 1, (self.numT - 1) do					-- calculate previous label and apply it
		self.activeT = (self.activeT % self.numT) + 1
	end	
	
end