--[[
#########################################################################################
# THE MAIN FILE - the root of the program												#
#########################################################################################
--]]

require("utilities.util")
require("utilities.vars")

require("gui.cButton")
require("gui.cCombo")
require("gui.cText")

require("states.sMenuMain")
require("states.sMenuNG")
require("states.sMenuOp")
require("states.sMenuOpGameplay")
require("states.sMenuOpControls")
require("states.sMenuHighscores")
require("states.sSPgame")
require("states.sSaveScore")

require("class.cGenerator")
require("class.cPieces")
require("class.cBoard")
require("class.cGameControl")
require("class.cHighscores")
require("class.cOptions")


-- CALLBACK RUN AT THE BEGINNING OF THE PROGRAM - loads stuff ---------------------------
function love.load()
				
	-- Initialize the program with the 'main menu' state
	state = sMenuMain.create()
	
	-- Simple initial setup
	love.graphics.setBackgroundColor(color["background"])
	
	-- HIGHSCORES LOAD
	filesave = "LTsave.sav"
	if not love.filesystem.isFile(filesave) then cHighscores:new(filesave, "BOT", 1000)
	else cHighscores:load(filesave) end
	
	-- GAMEPLAY & CONTROLS LOAD
	fileoptions = "LToptions.sav"
	--cOptions:save(fileoptions)
	if not love.filesystem.isFile(fileoptions) then cOptions:save(fileoptions)
	else cOptions:load(fileoptions) end
	
end


-- CALLBACK RUN EVERY FRAME, TO DRAW THE CURRENT CURRENT STATE --------------------------
function love.draw()

	-- draw the current state
	state:draw()

end


-- CALLBACK RUN EVERY FRAME, TO UPDATE THE CURRENT CURRENT STATE ------------------------
function love.update(dt)
	
	-- update state
	state:update(dt)

end


-- CALLBACK RUN EVERY TIME A KEYBOARD BUTTON IS PRESSED ---------------------------------
function love.keypressed(key, unicode)
	
	-- call appropriate handling function	
	state:keypressed(key, unicode)

end


-- CALLBACK RUN WHEN GAME QUITS ---------------------------------------------------------

function love.quit()

	-- saves scores (?) and options to file
	cOptions:save(fileoptions)
	
end