--[[
#########################################################################################
# THE MAIN MENU - handles the main menu state											#
#########################################################################################
--]]

sMenuMain = {}
sMenuMain.__index = sMenuMain


--cButton.create(text, x, y, font, offColor, onColor, combo)


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sMenuMain.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sMenuMain) -- make its metatable this very own
	
	-- first define the X and Y position for the menu (top-left corner)
	local posX = 30
	local posY = (love.graphics.getHeight() / 2) - (((4 * font["menu"]:getHeight()) + (3 * ((font["menu"]:getHeight() / 3)))) / 2)

	-- create the buttons it holds (after all, the main menu is just a bunch of buttons...)
	temp.button = {}
	temp.button[1] = cButton.create("/ New Game", posX, posY, "menu", 2, "foreground")
	temp.button[2] = cButton.create("/ Options", posX, posY + (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3)), "menu", 2, "foreground")
	temp.button[3] = cButton.create("/ Highscores", posX, posY + (2 * (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3))), "menu", 2, "foreground")
	temp.button[4] = cButton.create("/ Quit", posX, posY + (3 * (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3))), "menu", 2, "foreground")
	
	temp.active = 1
	temp.button[temp.active].hover = true

	return temp
	
end


-- THIS FUNCTION DRAWS THE MAIN MENU
function sMenuMain:draw()

	-- draw a logo
	drawLogo (40, "title")
	
	-- loop each button and draw it
	for n,b in pairs(self.button) do
		b:draw()
	end

end


-- THIS FUNCTION UPDATES THE MAIN MENU (nothing here)
function sMenuMain:update()
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sMenuMain:keypressed(key)

	-- 1. Up key
	if key == "down" then
		self.button[self.active].hover = false			-- un-hover actual active button
		self.active = (self.active % #self.button) + 1	-- calculate next button
		self.button[self.active].hover = true			-- hover it
	
	-- 2. Down key
	elseif key == "up" then
		self.button[self.active].hover = false				-- un-hover actual active button
		for i = 1, (#self.button - 1) do					-- calculate next button
			self.active = (self.active % #self.button) + 1
		end	
		self.button[self.active].hover = true				-- hover it
	
	-- 3. Return key
	elseif key == "return" then	
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n ==1 then
					-- new game menu
					state = sMenuNG.create()
				elseif n ==2 then
					-- options menu
					state = sMenuOp.create()
				elseif n == 3 then
					-- highscores menu
					state = sMenuHighscores.create()
				elseif n == 4 then
					-- quit game
					love.event.push("quit")
				end
			end
		end		
	
	-- 4. Escape key
	elseif key == "escape" then
		love.event.push("quit")
	end
end