--[[
#########################################################################################
# THE NEW GAME MENU - handles the new main menu state									#
#########################################################################################
--]]

sMenuNG = {}
sMenuNG.__index = sMenuNG


--cButton.create(text, x, y, font, offColor, onColor, combo)


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sMenuNG.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sMenuNG) -- make its metatable this very own 
	
	-- first define the X and Y position for the menu (top-left corner)
	local posX = 30
	local posY = (love.graphics.getHeight() / 2) - (((4 * font["menu"]:getHeight()) + (3 * ((font["menu"]:getHeight() / 3)))) / 2)

	-- create the buttons it holds (after all, the main menu is just a bunch of buttons...)
	temp.button = {}
	temp.button[1] = cButton.create("// Single Player", posX, posY, "menu", 2, "foreground")
	temp.button[2] = cButton.create("// 2P Competitive", posX, posY + (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3)), "menu", 2, "foreground")
	temp.button[3] = cButton.create("// 2P Co-operative", posX, posY + (2 * (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3))), "menu", 2, "foreground")
	temp.button[4] = cButton.create("// Back", posX, posY + (3 * (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3))), "menu", 2, "foreground")
	
	temp.active = 1
	temp.button[temp.active].hover = true
	
	return temp
	
end


-- THIS FUNCTION DRAWS THE MAIN MENU
function sMenuNG:draw()

	-- draw a logo
	drawLogo (40, "title")
		
	-- loop each button and draw it
	for n,b in pairs(self.button) do
		b:draw()
	end
	
	-- draw instructions of current selected button
	-- 1. set font
	love.graphics.setFont(font["default"])
	-- 2. set color
	love.graphics.setColor(color[3])
	if self.active == 1 then
		love.graphics.printf("Starts a single player game\n[ based on the chosen gameplay options ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 2 then
		love.graphics.printf("Starts a competitive game between 2 players\n[ when a player clears a line the other gets additional blocks ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 3 then
		love.graphics.printf("Starts a cooperative game between 2 players\n[ a line is cleared only when both players fill their part of it ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 4 then
		love.graphics.printf("Returns to the main menu", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	end
	
end


-- THIS FUNCTION UPDATES THE MAIN MENU (nothing here)
function sMenuNG:update() --NOTE: despite not being used here, the dt var is here to maintain coherency with other states
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sMenuNG:keypressed(key)

	-- 1. Up key
	if key == "down" then
		self.button[self.active].hover = false			-- un-hover actual active button
		self.active = (self.active % #self.button) + 1	-- calculate next button
		self.button[self.active].hover = true			-- hover it
	
	-- 2. Down key
	elseif key == "up" then
		self.button[self.active].hover = false				-- un-hover actual active button
		for i = 1, (#self.button - 1) do					-- calculate next button
			self.active = (self.active % #self.button) + 1
		end	
		self.button[self.active].hover = true				-- hover it
	
	-- 3. Return key
	elseif key == "return" then	
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n ==1 then
					-- new SP GAME
					state = sSPgame.create()
				elseif n ==2 then
					-- new 2P COMPETITIVE
				elseif n == 3 then
					-- new 2P CO-OPT
				elseif n == 4 then
					-- main menu
					state = sMenuMain.create()
				end
			end
		end		
	
	-- 4. Escape key
	elseif key == "escape" then
		-- calls previous (main) menu
		state = sMenuMain.create()
	end
end