--[[
#########################################################################################
# THE OPTIONS MENU - handles the options menu state										#
#########################################################################################
--]]

sMenuOp = {}
sMenuOp.__index = sMenuOp


--cButton.create(text, x, y, font, offColor, onColor, combo)


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sMenuOp.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sMenuOp) -- make its metatable this very own
	
	-- first define the X and Y position for the menu (top-left corner)
	local posX = 30
	local posY = (love.graphics.getHeight() / 2) - (((3 * font["menu"]:getHeight()) + (2 * ((font["menu"]:getHeight() / 3)))) / 2)

	-- create the buttons it holds (after all, the main menu is just a bunch of buttons...)
	temp.button = {}
	temp.button[1] = cButton.create("// Gameplay", posX, posY, "menu", 2, "foreground")
	temp.button[2] = cButton.create("// Controls", posX, posY + (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3)), "menu", 2, "foreground")
	temp.button[3] = cButton.create("// Back", posX, posY + (2 * (font["menu"]:getHeight() + (font["menu"]:getHeight() / 3))), "menu", 2, "foreground")
	
	temp.active = 1
	temp.button[temp.active].hover = true
	
	return temp
	
end


-- THIS FUNCTION DRAWS THE MENU
function sMenuOp:draw()

	-- draw a logo
	drawLogo (40, "title")
		
	-- loop each button and draw it
	for n,b in pairs(self.button) do
		b:draw()
	end

end


-- THIS FUNCTION UPDATES THE MENU (nothing here)
function sMenuOp:update() --NOTE: despite not being used here, the dt var is here to maintain coherency with other states
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sMenuOp:keypressed(key)

	-- 1. Up key
	if key == "down" then
		self.button[self.active].hover = false			-- un-hover actual active button
		self.active = (self.active % #self.button) + 1	-- calculate next button
		self.button[self.active].hover = true			-- hover it
	
	-- 2. Down key
	elseif key == "up" then
		self.button[self.active].hover = false				-- un-hover actual active button
		for i = 1, (#self.button - 1) do					-- calculate next button
			self.active = (self.active % #self.button) + 1
		end	
		self.button[self.active].hover = true				-- hover it
	
	-- 3. Return key
	elseif key == "return" then	
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n ==1 then
					-- gameplay options menu
					state = sMenuOpGameplay.create()
				elseif n ==2 then
					-- controls menu
					state = sMenuOpControls.create()
				elseif n == 3 then
					-- main menu
					state = sMenuMain.create()
				end
			end
		end		
	
	-- 4. Escape key
	elseif key == "escape" then
		-- calls previous (main) menu
		state = sMenuMain.create()
	end
end