--[[
#########################################################################################
# THE CONTROL OPTIONS MENU - handles the control options menu state						#
#########################################################################################
--]]

sMenuOpControls = {}
sMenuOpControls.__index = sMenuOpControls


--cButton.create(text, x, y, font, offColor, onColor, combo)


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sMenuOpControls.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sMenuOpControls) -- make its metatable this very own
	
	-- first define the X and Y position for the menu (top-left corner)
	local posX = 30
	local posX2 = 450
	local posY = (love.graphics.getHeight() - (2 * font["medium"]:getHeight())) - ((8 * font["medium"]:getHeight()) + (7 * ((font["medium"]:getHeight() / 3))))
	--local posY = (love.graphics.getHeight() / 2) - (((8 * font["medium"]:getHeight()) + (7 * ((font["medium"]:getHeight() / 3)))) / 2)

	-- create the buttons it holds (after all, the main menu is just a bunch of buttons...)
	temp.button = {}
	temp.button[1] = cButton.create("\t\t>> Left", posX, posY, "medium", 2, "foreground")
	temp.button[2] = cButton.create("\t\t>> Right", posX, posY + (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3)), "medium", 2, "foreground")
	temp.button[3] = cButton.create("\t\t>> Rotate", posX, posY + (2 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[4] = cButton.create("\t\t>> Down", posX, posY + (3 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[5] = cButton.create("\t\t>> Pause", posX, posY + (4 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[6] = cButton.create("\t\t>> Restart", posX, posY + (5 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[7] = cButton.create("\t\t>> Quit", posX, posY + (6 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[8] = cButton.create(">> P2 Left", posX2, posY, "medium", 2, "foreground")
	temp.button[9] = cButton.create(">> P2 Right", posX2, posY + (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3)), "medium", 2, "foreground")
	temp.button[10] = cButton.create(">> P2 Rotate", posX2, posY + (2 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[11] = cButton.create(">> P2 Down", posX2, posY + (3 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[12] = cButton.create("// Back", posX, posY + (8 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")

	temp.active = 1
	temp.button[temp.active].hover = true
	
	temp.ctrlabel = {}
	for i = 1 , (#temp.button - 1) do
		temp.ctrlabel[i] = cButton.create(PcontrolMap[i], temp.button[i].x + 225, temp.button[i].y, "medium", 3, 6)--"foreground")
	end
	
	temp.changing = 0
	
	return temp
	
end


-- THIS FUNCTION DRAWS THE MENU
function sMenuOpControls:draw()

	-- draw a logo
	drawLogo (40, "title")
		
	-- loop each button and draw it
	for n,b in pairs(self.button) do
		b:draw()
	end
	for n,b in pairs(self.ctrlabel) do
		b:draw()
	end
	
	-- draw some text
	-- 1. set font
	love.graphics.setFont(font["menu"])
	-- 2. set color
	love.graphics.setColor(color[5])
	love.graphics.print("Player 1:", 60, 170)
	love.graphics.print("Player 2:", 450, 170)


end


-- THIS FUNCTION UPDATES THE MENU (nothing here)
function sMenuOpControls:update() --NOTE: despite not being used here, the dt var is here to maintain coherency with other states
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sMenuOpControls:keypressed(key)

	if self.changing ~= 0 then
		-- key change mode!!
		-- first make sure there is no other command associated with this key
		local unused = true
		for i = 1, #PcontrolMap do
			if PcontrolMap[i] == key and i ~= self.changing then unused = false end
		end
		-- if key can be assigned, then assign it and stop change mode
		if unused then
			PcontrolMap[self.changing] = key
			self.ctrlabel[self.changing].text = key
			self.ctrlabel[self.changing].hover = false
			self.changing = 0
		end	
		
	else
		-- just move between buttons
		-- 1. Up key
		if key == "down" then
			self.button[self.active].hover  = false			-- un-hover actual active button
			self.active = (self.active % #self.button) + 1	-- calculate next button
			self.button[self.active].hover = true			-- hover it
	
		-- 2. Down key
		elseif key == "up" then
			self.button[self.active].hover = false				-- un-hover actual active button
			for i = 1, (#self.button - 1) do					-- calculate next button
				self.active = (self.active % #self.button) + 1
			end	
			self.button[self.active].hover = true				-- hover it
	
		-- 3. Return key
		elseif key == "return" then	
			-- ...check each button to see which one was pressed and act accordingly
			for n,b in pairs(self.button) do
				if b.hover then
					if n == 12 then
						-- options menu
						state = sMenuOp.create()
					else
						-- make that button change
						self.changing = n
						self.ctrlabel[n].hover = true
					end
				end
			end		
		
		-- 4. Escape key
		elseif key == "escape" then
			-- calls previous (main) menu
			state = sMenuMain.create()
		end
	end
end