--[[
#########################################################################################
# THE GAMEPLEY OPTIONS MENU - handles the gameplay options menu state					#
#########################################################################################
--]]

sMenuOpGameplay = {}
sMenuOpGameplay.__index = sMenuOpGameplay


--cButton.create(text, x, y, font, offColor, onColor, combo)
--cCombo.create(label, text[], x, y, font, offColor, onColor)


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sMenuOpGameplay.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sMenuOpGameplay) -- make its metatable this very own
		
	-- first define the X and Y position for the menu (top-left corner)
	local posX = 30
	local posY = (love.graphics.getHeight() / 2) - (((5 * font["medium"]:getHeight()) + (4 * ((font["medium"]:getHeight() / 3)))) / 2)

	-- create the buttons it holds (after all, the main menu is just a bunch of buttons...)
	temp.button = {}
	
	temp.button[1] = cCombo.create("/// Generator", {"random","bag","TGM","bastard"}, posX, posY, "medium", 2, "foreground")
	temp.button[1].activeT = tetraGen
	temp.button[2] = cCombo.create("/// Board Size", {"standard", "fat", "short"}, posX, posY + (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3)), "medium", 2, "foreground")
	temp.button[2].activeT = boardSize
	temp.button[3] = cCombo.create("/// Blindmode", {"on", "off"}, posX, posY + (2 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[3].activeT = blindmode
	temp.button[4] = cCombo.create("/// Fullscreen", {"on", "off"}, posX, posY + (3 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	temp.button[4].activeT = fullscreen
	temp.button[5] = cButton.create("/// Back", posX, posY + (4 * (font["medium"]:getHeight() + (font["medium"]:getHeight() / 3))), "medium", 2, "foreground")
	
	temp.active = 1
	temp.button[temp.active].hover = true
	
	return temp
	
end


-- THIS FUNCTION DRAWS THE MENU
function sMenuOpGameplay:draw()

	-- draw a logo
	drawLogo (40, "title")
		
	-- loop each button and draw it
	for n,b in pairs(self.button) do
		b:draw()
	end
	
	-- draw an explanation of the selected option
	-- 1. set font
	love.graphics.setFont(font["default"])
	-- 2. set color
	love.graphics.setColor(color[3])
	if self.active == 1 then
		love.graphics.printf("Selects the algorithm used to generate tetraminoes\n[ Note: 'bastard' gives preference to worst pieces ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 2 then
		love.graphics.printf("Selects the board size for the Single Player game\n[ standart - 10x20 ] [ fat - 20x20 ] [ short - 20x10 ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 3 then
		love.graphics.printf("Toggles Blindmode on/off\n[ If enabled, hides next piece from player ]", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 4 then
		love.graphics.printf("Toggles fullscreen on/off", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	elseif self.active == 5 then
		love.graphics.printf("Returns to the Options menu", 30, love.graphics.getHeight() - (5 * font["default"]:getHeight()), love.graphics.getWidth() - 60, "left")
	end
end


-- THIS FUNCTION UPDATES THE MENU (nothing here)
function sMenuOpGameplay:update() --NOTE: despite not being used here, the dt var is here to maintain coherency with other states
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sMenuOpGameplay:keypressed(key)

	-- 1. Up key
	if key == "down" then
		self.button[self.active].hover = false			-- un-hover actual active button
		self.active = (self.active % #self.button) + 1	-- calculate next button
		self.button[self.active].hover = true			-- hover it
	
	-- 2. Down key
	elseif key == "up" then
		self.button[self.active].hover = false				-- un-hover actual active button
		for i = 1, (#self.button - 1) do					-- calculate next button
			self.active = (self.active % #self.button) + 1
		end	
		self.button[self.active].hover = true				-- hover it
	
	-- 3. Right key
	elseif (key == "right" or key == "left") then
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n ~= 5 then
					-- change the combo
					if key == "right" then
						b:nextLabel ()
					elseif key == "left" then
						b:previousLabel ()
					end
					tetraGen = self.button[1].activeT
					cGenerator.style = tetraGen
					boardSize = self.button[2].activeT
					blindmode = self.button[3].activeT
					-- update screen mode only if necessary
					if n == 4 then
						fullscreen = self.button[4].activeT
						if fullscreen == 1 then
							if love.graphics.checkMode(800, 600, true) then love.graphics.setMode(800, 600, true) end
						else
							love.graphics.setMode(800, 600, false)
						end
					end
				end
			end
		end	
			
	-- 3. Return key
	elseif key == "return" then	
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n == 1 then
					-- generator combo
					b:nextLabel ()
					tetraGen = self.button[1].activeT	
					cGenerator.style = self.button[1].activeT			
				elseif n ==2 then
					-- boardsize combo
					b:nextLabel ()
					boardSize = self.button[2].activeT
				elseif n == 3 then
					-- blindmode combo
					b:nextLabel ()
					blindmode = self.button[3].activeT
				elseif n == 4 then
					-- blindmode combo
					b:nextLabel ()
					blindmode = self.button[4].activeT
				elseif n == 5 then
					-- options menu
					self.setBoardSize() -- first save boardsize
					state = sMenuOp.create()
				end
			end
		end		
	
	-- 4. Escape key
	elseif key == "escape" then
		-- calls previous (main) menu
		self.setBoardSize() -- first save boardsize
		state = sMenuMain.create()
	end

end


-- function to be called when exiting state, to save the selected board size to the actual vars
function sMenuOpGameplay.setBoardSize()
	if boardSize == 1 then
		bW = 10
		bH = 20
	elseif boardSize == 2 then
		bW = 20
		bH = 20
	elseif boardSize == 3 then
		bW = 20
		bH = 10
	end	
end