--[[
#########################################################################################
# THE SINGLE-PLAYER GAME CLASS - handles the main game for one player					#
#########################################################################################
# Belongs to the LÖVE-ly Tetris project													#
# tv_user - 2012																		#
# Free to use for all purposes															#
#########################################################################################
--]]

sSPgame = {}
sSPgame.__index = sSPgame


-- THIS FUNCTION CREATES THE SP-GAME STATE
function sSPgame.create()
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sSPgame) -- make its metatable this very own (cSPgame)
	--temp.Game = cGameControl.create(128, 32, 2, 2)
	temp.Game = cGameControl.create((love.graphics.getWidth() / 2) - ((bW/2) * blockSize), (love.graphics.getHeight() / 2) - ((bH/2) * blockSize) + 80, 2, 2)
	temp.tx = (love.graphics.getWidth() / 2) + ((bW/2) * blockSize) + 20 	-- the X position to draw text right next to the board
	temp.ty = (love.graphics.getHeight() / 2) - ((bH/2) * blockSize) + 80 	-- the Y position to draw text right next to the board
	return temp
	
end


-- THIS FUNCTION DRAWS THE MAIN SP-GAME
function sSPgame:draw()

	-- 1. If game ended (over or victory), store a screenshot on a canvas and then switch to the "set highscore menu" state)
	if (self.Game.IsGameOver == true) or (self.Game.IsVictory == true) then
		-- 1.1 clear the canvas
		canvas:clear()
		-- 1.2 set drawing operations to canvas
		love.graphics.setCanvas(canvas)
		-- 1.3 draw everything
		self:drawGame ()
		-- 1.4 quit canvas rendering
		love.graphics.setCanvas()
		-- 1.5 switch to the other state
		state = sSaveScore.create(self.Game.score, self.Game.IsGameOver, false)
	else
	-- 2. If not, continue the game as usual
		self:drawGame ()
	end
	
end


-- THIS FUNCTION DRAWS EVERYTHING TO SCREEN
function sSPgame:drawGame ()
	-- 1. Draw the title
	drawLogo (40, "title")
	-- and subtitle
	love.graphics.setFont(font["smalltitle"]) -- set font
	love.graphics.setColor(color["dark"]) -- set color
	love.graphics.print("- SP Game -", (love.graphics.getWidth() / 2) - (font["smalltitle"]:getWidth("- SP Game -") / 2), 132)
	love.graphics.setColor(color["foreground"]) -- set color
	love.graphics.print("- SP Game -", (love.graphics.getWidth() / 2) - (font["smalltitle"]:getWidth("- SP Game -") / 2), 130)
	
	-- 2. Draws the game scene
	self.Game:DrawScene()
	
	-- 3. Draws some game info
	love.graphics.setFont(font["default"]) -- set font
	love.graphics.setColor(color["foreground"]) -- set color
	-- Next piece
	love.graphics.print("Next Piece", self.tx, self.ty)
	-- Score
	love.graphics.print("Score: " .. self.Game.score, self.tx, self.ty + 100)
	-- Level
	love.graphics.print("Level: " .. self.Game.level, self.tx, self.ty + 125)
	-- Num of lines cleared
	love.graphics.print("Lines cleared: " .. self.Game.Board.nLinDel, self.tx, self.ty + 150)
	-- Timeelapsed
	love.graphics.print("Time: " .. math.floor(self.Game.totaltime + 0.5) .. " sec", self.tx, self.ty + 175)
	-- Board size
	love.graphics.print("Size: " .. bW .. "x" .. bH, self.tx, self.ty + 200)
	-- Generator type
	if tetraGen == 1 then love.graphics.print("Generator: random", self.tx, self.ty + 225)
	elseif tetraGen == 2 then love.graphics.print("Generator: bag", self.tx, self.ty + 225)
	elseif tetraGen == 3 then love.graphics.print("Generator: TGM", self.tx, self.ty + 225)
	elseif tetraGen == 4 then love.graphics.print("Generator: bastard", self.tx, self.ty + 225) end
end


-- THIS FUNCTION UPDATES THE MAIN SP-GAME
function sSPgame:update(dt)

	-- updates the game
	if (not self.Game.IsGameOver) then
		self.Game:Update(dt)
	end
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sSPgame:keypressed(key)
	-- QUIT KEY pressed during game
	if key == PcontrolMap[7] then
		-- first save the score
		cHighscores:add(self.Game.score, "player")
		cHighscores:save(filesave)
		-- return to main menu
		state = sMenuMain.create() -- return to main menu
			
	-- RESTART KEY pressed during game
	elseif key == PcontrolMap[6] then
        -- save score
		cHighscores:add(self.Game.score, "player")
		cHighscores:save(filesave)
   		-- create a new game
		self.Game = cGameControl.create((love.graphics.getWidth() / 2) - ((bW/2) * blockSize), (love.graphics.getHeight() / 2) - ((bH/2) * blockSize) + 80, 2, 2)
   	else
   		-- ...or if player pressed another key, call the appropriate handling function
   		self.Game:ManageInp(key)
   	end

end	