--[[
#########################################################################################
# THE MAIN MENU - handles the main menu state											#
#########################################################################################
--]]

sSaveScore = {}
sSaveScore.__index = sSaveScore


-- THIS FUNCTION CREATES A TABLE with the main menu in it
function sSaveScore.create(score, over, saved)
	
	local temp = {} -- first create a temp table
	setmetatable(temp, sSaveScore) -- make its metatable this very own
	
	-- save if it was game over or victory
	temp.IsGameOver = over
	-- save the current score
	temp.score = score
	-- store a var that tells us if this is a re-call and a highscore was already saved
	temp.saved = saved
	
	if saved == false then
		-- test if we got a highscore or not
		local pos = cHighscores:test(score)
		if pos then
			-- save the position of the new highscore
			temp.scorePos = pos
			temp.IsHigh = true
			-- save score in appropriate array, but without a name yet
			cHighscores:add(score, "")

			-- create a textbox for name input
			-- cText.create(text, x, y, max, font, color)
			temp.textbox = cText.create("", 400, 180 + (pos * 30), 10, "medium", 1)
		else
			temp.saved = true
			--temp.IsHigh = false
		end
	end
	
	if temp.saved then
		-- if it was a highscore or not
		temp.IsHigh = saved -- NOTE: if its a recall, this will became true, it not, it will became false
		-- and create 2 buttons
		temp.button = {}
		temp.button[1] = cButton.create("<Restart>", (love.graphics.getWidth() / 4) - (font["menu"]:getWidth("<Restart>") / 2), love.graphics.getHeight() - 70, "menu", 2, "foreground")
		temp.button[2] = cButton.create("<Quit>", (love.graphics.getWidth() * 3/4) - (font["menu"]:getWidth("<Quit>") / 2), love.graphics.getHeight() - 70, "menu", 2, "foreground")
		temp.active = 1
		temp.button[temp.active].hover = true
	end

	return temp
	
end


-- THIS FUNCTION DRAWS THE MAIN MENU
function sSaveScore:draw()

	-- 1. DRAW THE CANVAS
	love.graphics.setColor(255,255,255,100)
	love.graphics.draw(canvas, 0, 0)
	
	-- 2. DRAW THE BACKGROUND BOX
	love.graphics.setColor(42,48,54,175)
	local x = 15
	love.graphics.rectangle("fill", x, x, love.graphics.getWidth() - (2 * x), love.graphics.getHeight() - (2 * x))
	
	-- 3. DRAW SCORES AND MESSAGES
	self:drawScores("title2", "smalltitle")
	
	-- 4. DRAW TEXTBOX (if available)
	if self.IsHigh and not self.saved then
		self.textbox:draw()
		-- also draw a box around it
		love.graphics.setColor(color["foreground"])
		love.graphics.setLine(1, "rough")
		love.graphics.rectangle("line", 60, 180 + (self.scorePos * 30), love.graphics.getWidth() - 120, 32)
	end
	
	-- 5. DRAW BUTTONS (if available)
	if self.saved then
		-- loop each button and draw it
		for n,b in pairs(self.button) do
			b:draw()
		end
	end
	
end


-- THIS FUNCTION JUST DRAWS THE HIGHSCORES TABLE
function sSaveScore:drawScores(f1, f2)

	-- 1. DRAW THE GAME OVER or VICTORY SPLASH
	if self.IsGameOver then
		love.graphics.setFont(font[f1]) -- set font
		love.graphics.setColor(color["dark"]) -- set color
		love.graphics.print("GAME OVER", (love.graphics.getWidth() / 2) - (font[f1]:getWidth("GAME OVER") / 2), 43)
		love.graphics.setColor(color[1]) -- set color
		love.graphics.print("GAME OVER", (love.graphics.getWidth() / 2) - (font[f1]:getWidth("GAME OVER") / 2), 40)
	else
		love.graphics.setFont(font[f1]) -- set font
		love.graphics.setColor(color["dark"]) -- set color
		love.graphics.print("OMG YOU WON!!", (love.graphics.getWidth() / 2) - (font[f1]:getWidth("OMG YOU WON!!") / 2), 43)
		love.graphics.setColor(color[1]) -- set color
		love.graphics.print("OMG YOU WON!!", (love.graphics.getWidth() / 2) - (font[f1]:getWidth("OMG YOU WON!!") / 2), 40)
	end
	
	-- 2. if score was already saved, then we just show the scores as a normal screen
	if self.saved then
		-- 2.1 draw a little splashy based on highscore or not
		if self.IsHigh then
			love.graphics.setFont(font[f2]) -- set font
			love.graphics.setColor(color["dark"]) -- set color
			love.graphics.print("New Highscore!!", (love.graphics.getWidth() / 2) - (font[f2]:getWidth("New Highscore!!") / 2), 133)		
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("New Highscore!!", (love.graphics.getWidth() / 2) - (font[f2]:getWidth("New Highscore!!") / 2), 130)		
		else
			love.graphics.setFont(font[f2]) -- set font
			love.graphics.setColor(color["dark"]) -- set color
			love.graphics.print("Your score: " .. self.score, (love.graphics.getWidth() / 2) - (font[f2]:getWidth("Your score: ".. self.score) / 2), 133)		
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("Your score: " .. self.score, (love.graphics.getWidth() / 2) - (font[f2]:getWidth("Your score: ".. self.score) / 2), 130)		
		end
		-- 2.2 draw scores table
		love.graphics.setFont(font["medium"]) -- set font
		love.graphics.setColor(color[6]) -- set color
		-- 2.2.1 draw position
		love.graphics.print("Place", 100, 180)		
		-- 2.2.2 draw score
		love.graphics.print("Score", 250, 180)	
		-- 2.2.3 draw name
		love.graphics.print("Name", 400, 180)
		-- 2.2.4 draw every score	
		for i = 1, cHighscores.places do
			-- draw position
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("\t>> " .. i , 100, 180 + i*30)		
			-- draw score
			love.graphics.setColor(color[3]) -- set color
			love.graphics.print(cHighscores.score[i] , 250, 180 + i*30)	
			-- draw name
			love.graphics.setColor(color[7]) -- set color
			love.graphics.print(cHighscores.name[i] , 400, 180 + i*30)
		end
	
	else
		-- 3. if not saved, then DRAW INSTRUCTIONS BASED ON HIGHSCORE OR NOT
		if self.IsHigh then
			love.graphics.setFont(font[f2]) -- set font
			love.graphics.setColor(color["dark"]) -- set color
			love.graphics.print("New Highscore!!", (love.graphics.getWidth() / 2) - (font[f2]:getWidth("New Highscore!!") / 2), 133)		
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("New Highscore!!", (love.graphics.getWidth() / 2) - (font[f2]:getWidth("New Highscore!!") / 2), 130)		
			-- also draw some instructions
			love.graphics.setFont(font["medium"])
			love.graphics.setColor(color[2])
			love.graphics.print("Enter a name", (love.graphics.getWidth() / 2) - (font["medium"]:getWidth("Enter a name") / 2), love.graphics.getHeight() - 60)
		else
			love.graphics.setFont(font[f2]) -- set font
			love.graphics.setColor(color["dark"]) -- set color
			love.graphics.print("Your score: " .. self.score, (love.graphics.getWidth() / 2) - (font[f2]:getWidth("Your score: ".. self.score) / 2), 133)		
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("Your score: " .. self.score, (love.graphics.getWidth() / 2) - (font[f2]:getWidth("Your score: ".. self.score) / 2), 130)		
		end
		
		-- 4. DRAW EVERY HIGHSCORE
		love.graphics.setFont(font["medium"]) -- set font
		love.graphics.setColor(color[6]) -- set color
		-- draw position
		love.graphics.print("Place", 100, 180)		
		-- draw score
		love.graphics.print("Score", 250, 180)	
		-- draw name
		love.graphics.print("Name", 400, 180)
		
		for i = 1, cHighscores.places do
			-- draw position
			love.graphics.setColor(color[4]) -- set color
			love.graphics.print("\t>> " .. i , 100, 180 + i*30)		
			-- draw name & score...
			if self.IsHigh then
				if i ~= self.scorePos then 
					-- draw both score...
					love.graphics.setColor(color[3]) -- set color
					love.graphics.print(cHighscores.score[i] , 250, 180 + i*30)
					-- ...and name	
					love.graphics.setColor(color[7]) -- set color
					love.graphics.print(cHighscores.name[i] , 400, 180 + i*30)
				else
					-- just draw the score, because the name will be in the textbox
					love.graphics.setColor(color[3]) -- set color
					love.graphics.print(self.score , 250, 180 + i*30)	
				end
			else
				love.graphics.setColor(color[7]) -- set color
				love.graphics.print(cHighscores.name[i] , 400, 180 + i*30)
			end	
		end
	end	
end


-- THIS FUNCTION UPDATES THE MAIN MENU (nothing here)
function sSaveScore:update()
	
end


-- THIS FUNCTION IS CALLED WHEN A KEY IS PRESSED, and handles it
function sSaveScore:keypressed(key, unicode)

	if key == "escape" then
		-- return to main menu
		state = sMenuMain.create()
	else
		-- lets see if this is a re-call, and if so, there are two buttons on the screen which we must handle
		if self.saved then
			self:handleButtons(key)
		else	
			-- if we have a new highscore, then we must handle the input for the textbox
			if self.IsHigh then
				if key == "return" then
					-- save name
					cHighscores.name[self.scorePos] = self.textbox.text
					-- save to file
					cHighscores:save(filesave)
					-- re-call this state, but now without the need for a textbox
					state = sSaveScore.create(self.score, self.IsGameOver, true)
				else
					-- update text in textbox	
					self.textbox:keypressed(key, unicode)
				end	
			end
		end	
	end
	
end


-- Handles the input for the buttons (when they exist)
function sSaveScore:handleButtons(key)
	-- 1. Right key
	if key == "right" then
		self.button[self.active].hover = false			-- un-hover actual active button
		self.active = (self.active % #self.button) + 1	-- calculate next button
		self.button[self.active].hover = true			-- hover it
	
	-- 2. Left key
	elseif key == "left" then
		self.button[self.active].hover = false				-- un-hover actual active button
		for i = 1, (#self.button - 1) do					-- calculate next button
			self.active = (self.active % #self.button) + 1
		end	
		self.button[self.active].hover = true				-- hover it
	
	-- 3. Return key
	elseif key == "return" then	
		-- ...check each button to see which one was pressed and act accordingly
		for n,b in pairs(self.button) do
			if b.hover then
				if n ==1 then
					-- new game menu
					state = sSPgame.create()
				elseif n ==2 then
					-- options menu
					state = sMenuMain.create()
				end
			end
		end	
	end
end